@@ -140,12 +140,12 @@ function ubufoxReportBug(event) {
 
 function ubufoxGetHelpOnline(event)
 {
-  openUILink("https://launchpad.net/distros/ubuntu/hardy/+sources/firefox-3.0/+gethelp", event, false, true);
+  openUILink("https://launchpad.net/distros/ubuntu/intrepid/+sources/firefox-3.0/+gethelp", event, false, true);
 }
 
 function ubufoxHelpTranslateLaunchpad(event)
 {
-  openUILink("https://launchpad.net/distros/ubuntu/hardy/+sources/firefox-3.0/+translate", event, false, true);
+  openUILink("https://launchpad.net/distros/ubuntu/intrepid/+sources/firefox-3.0/+translate", event, false, true);
 }
 
 function ubufoxCheckExecutable(filename)
