@@ -171,6 +171,10 @@ nsPluginInstallerWizard.prototype.createPluginSetGroupBox = function () {
   return gbox;
 }
 
+function doToggleInstallPluginEvent(e) {
+  gPluginInstaller.toggleInstallPlugin(e);
+}
+
 nsPluginInstallerWizard.prototype.showPluginList = function () {
   var toReplace = null;
 
@@ -203,55 +207,33 @@ nsPluginInstallerWizard.prototype.showPluginList = function () {
     lastSibling = groupBox;
     this.mPluginGroupBoxes.push(groupBox);
 
-    var vbox = document.createElement("vbox");
-    vbox.setAttribute("id", "pluginList");
-    vbox.setAttribute("flex", "1");
-    vbox.setAttribute("style","overflow: auto;");
-    groupBox.appendChild(vbox);
-
-    var radiogroup = document.createElement("radiogroup");
+    var radiogroup = document.createElement("richlistbox");
     radiogroup.setAttribute("flex", "1");
-    vbox.appendChild(radiogroup);
+    groupBox.appendChild(radiogroup);
+    radiogroup.addEventListener("select", doToggleInstallPluginEvent, false);
 
     // OK, lets add the "None" option first
-    var myRadio = null;
-
     var first = true;
     for (var i = 0; i < pluginInfoSet.length; i++) {
-      var table = document.createElement("table");
-      table.setAttribute("class", "plugin-row-table");
-
-      var row = document.createElement("tr");
-      var cellMyRadio = document.createElement("td");
-      cellMyRadio.setAttribute("class", "plugin-radio-cell");
-
       var pluginInfo = pluginInfoSet[i];
-      // create the radio
-      myRadio = document.createElement("radio");
-      cellMyRadio.appendChild(myRadio);
-      row.appendChild(cellMyRadio);
+      var rli = document.createElement("richlistitem");
+      rli.setAttribute("style", "border-bottom: dotted 1px lightgrey; padding: 0.5em 1em 0.5em 1em");
+      rli._ubufoxPluginInfo = pluginInfo;
+      rli._ubufoxPluginInfoMimeType = mimetype;
+      radiogroup.appendChild(rli);
 
-      myRadio.setAttribute("selected", "false");
-      // XXXlocalize (nit)
-      if(first) {
-	myRadio.setAttribute("selected", "true");
-	first = false;
-	gPluginInstaller.toggleInstallPlugin(mimetype, pluginInfo.pid, myRadio);
-      }
+      var distributorImageWrap = document.createElement("vbox");
 
-      myRadio.setAttribute("oncommand", "gPluginInstaller.toggleInstallPlugin('" + mimetype + "', '" + pluginInfo.pid + "',  this)");
-      myRadio.setAttribute("label", pluginInfo.name + " " + (pluginInfo.version ? pluginInfo.version : ""));
-      myRadio.setAttribute("flex", "1");
+      var spacer = document.createElement("hbox");
+      spacer.setAttribute("flex", "1");
+      distributorImageWrap.appendChild(spacer);
 
       var distributorImage = document.createElement("image");
+      distributorImageWrap.appendChild(distributorImage);
+      distributorImageWrap.setAttribute("style", "vertical-align: middle");
+      distributorImage.setAttribute("style", "vertical-align: middle");
+      distributorImageWrap.setAttribute("flex", "0");
       distributorImage.setAttribute("class", "distributor-image");
-
-      var cellDistributorImage = document.createElement("td");
-      cellDistributorImage.setAttribute("class", "cell-distributor-image");
-
-      cellDistributorImage.appendChild(distributorImage);
-      row.appendChild(cellDistributorImage);
-
       if(pluginInfo.XPILocation && pluginInfo.XPILocation.indexOf("apt:") == 0) {
 	distributorImage.setAttribute("src", "chrome://ubufox/content/ubuntulogo32.png");
 	pluginInfo.IconUrl = "chrome://ubufox/content/ubuntulogo32.png";
@@ -262,17 +244,33 @@ nsPluginInstallerWizard.prototype.showPluginList = function () {
 	} else {
 	  distributorImage.setAttribute("src", pluginInfo.IconUrl);
 	}
+      } 
+
+      spacer = document.createElement("hbox");
+      spacer.setAttribute("flex", "1");
+      distributorImageWrap.appendChild(spacer);
+
+      rli.appendChild(distributorImageWrap);
+
+      var nameAndDesc = document.createElement("vbox");
+      rli.appendChild(nameAndDesc);
+
+      var nameLabel = document.createElement("label");
+      nameLabel.setAttribute("value", pluginInfo.name + " " + (pluginInfo.version ? pluginInfo.version : ""));
+      nameLabel.setAttribute("style", "font-weight: bold");
+      nameAndDesc.appendChild(nameLabel);
+
+      var descDesc = document.createElement("description");
+      if (!pluginInfo.desc) {
+        pluginInfo.desc = "No description found in plugin database. \nReport a bug to ubuntu-mozillateam@lists.ubuntu.com";
       }
-
-      table.appendChild(row);
-
-      row.setAttribute("flex", "1");
-      cellMyRadio.setAttribute("flex", "1");
-
-      radiogroup.appendChild(table);
-
+      descDesc.appendChild(document.createTextNode(pluginInfo.desc));
+      descDesc.setAttribute("style", "white-space: pre;");
+      nameAndDesc.appendChild(descDesc);
     }
 
+    radiogroup.selectedIndex = 0;
+
     if (pluginInfo.InstallerShowsUI == "true")
       hasPluginWithInstallerUI = true;
 
@@ -286,15 +284,17 @@ nsPluginInstallerWizard.prototype.showPluginList = function () {
   this.canRewind(false);
 }
 
-nsPluginInstallerWizard.prototype.toggleInstallPlugin = function (aMimetype, aPid, aCheckbox) {
+nsPluginInstallerWizard.prototype.toggleInstallPlugin = function (e) {
+  var selectedItem = e.target.selectedItem;
+  var mime = selectedItem._ubufoxPluginInfoMimeType;
+  this.mMimeTypePluginSelections[mime] = selectedItem._ubufoxPluginInfo.pid;
 
-  this.mMimeTypePluginSelections[aMimetype] = aPid;
-  count = 0;
+  let count  = 0;
   for (mime in this.mMimeTypePluginSelections) {
     if(this.mMimeTypePluginSelections[mime] && this.mMimeTypePluginSelections[mime] != "-1")
       count++;
   }
-
+ 
   // if no plugins are checked, don't allow to advance
   if (count > 0)
     this.canAdvance(true);
